"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.approveCollectionAuthority = exports.getApproveCollectionAuthorityInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getApproveCollectionAuthorityInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.u8()]], { description: 'ApproveCollectionAuthorityInstructionData' }), (value) => ({
        ...value,
        discriminator: 23,
    }));
}
exports.getApproveCollectionAuthorityInstructionDataSerializer = getApproveCollectionAuthorityInstructionDataSerializer;
function approveCollectionAuthority(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const collectionAuthorityRecordAccount = input.collectionAuthorityRecord;
    const newCollectionAuthorityAccount = input.newCollectionAuthority;
    const updateAuthorityAccount = input.updateAuthority ?? context.identity;
    const payerAccount = input.payer ?? context.payer;
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent;
    keys.push({
        pubkey: collectionAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionAuthorityRecordAccount, true),
    });
    keys.push({
        pubkey: newCollectionAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionAuthorityAccount, false),
    });
    signers.push(updateAuthorityAccount);
    keys.push({
        pubkey: updateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    if (rentAccount) {
        keys.push({
            pubkey: rentAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
        });
    }
    const data = getApproveCollectionAuthorityInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.approveCollectionAuthority = approveCollectionAuthority;
//# sourceMappingURL=approveCollectionAuthority.js.map