"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.burnV1 = exports.getBurnV1InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getBurnV1InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['burnV1Discriminator', s.u8()],
        ['amount', s.u64()],
    ], { description: 'BurnV1InstructionData' }), (value) => ({
        ...value,
        discriminator: 41,
        burnV1Discriminator: 0,
    }));
}
exports.getBurnV1InstructionDataSerializer = getBurnV1InstructionDataSerializer;
function burnV1(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const authorityAccount = input.authority ?? context.identity;
    const collectionMetadataAccount = input.collectionMetadata ?? {
        ...programId,
        isWritable: false,
    };
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const editionAccount = input.edition ?? { ...programId, isWritable: false };
    const tokenAccount = input.token;
    const masterEditionAccount = input.masterEdition ?? {
        ...programId,
        isWritable: false,
    };
    const masterEditionMintAccount = input.masterEditionMint ?? {
        ...programId,
        isWritable: false,
    };
    const masterEditionTokenAccount = input.masterEditionToken ?? {
        ...programId,
        isWritable: false,
    };
    const editionMarkerAccount = input.editionMarker ?? {
        ...programId,
        isWritable: false,
    };
    const tokenRecordAccount = input.tokenRecord ?? {
        ...programId,
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, true),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, true),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    keys.push({
        pubkey: masterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionAccount, true),
    });
    keys.push({
        pubkey: masterEditionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionMintAccount, false),
    });
    keys.push({
        pubkey: masterEditionTokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionTokenAccount, false),
    });
    keys.push({
        pubkey: editionMarkerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionMarkerAccount, true),
    });
    keys.push({
        pubkey: tokenRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenRecordAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    const data = getBurnV1InstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.burnV1 = burnV1;
//# sourceMappingURL=burnV1.js.map