"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEscrowAccount = exports.getCreateEscrowAccountInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getCreateEscrowAccountInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.u8()]], {
        description: 'CreateEscrowAccountInstructionData',
    }), (value) => ({ ...value, discriminator: 38 }));
}
exports.getCreateEscrowAccountInstructionDataSerializer = getCreateEscrowAccountInstructionDataSerializer;
function createEscrowAccount(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const escrowAccount = input.escrow;
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const tokenAccountAccount = input.tokenAccount;
    const editionAccount = input.edition ??
        (0, accounts_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const authorityAccount = input.authority;
    keys.push({
        pubkey: escrowAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowAccount, true),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: tokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountAccount, false),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    if (authorityAccount) {
        signers.push(authorityAccount);
        keys.push({
            pubkey: authorityAccount.publicKey,
            isSigner: true,
            isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
        });
    }
    const data = getCreateEscrowAccountInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createEscrowAccount = createEscrowAccount;
//# sourceMappingURL=createEscrowAccount.js.map