"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMetadataAccountV2 = exports.getCreateMetadataAccountV2InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getCreateMetadataAccountV2InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['data', (0, types_1.getDataV2Serializer)(context)],
        ['isMutable', s.bool()],
    ], { description: 'CreateMetadataAccountV2InstructionData' }), (value) => ({
        ...value,
        discriminator: 16,
    }));
}
exports.getCreateMetadataAccountV2InstructionDataSerializer = getCreateMetadataAccountV2InstructionDataSerializer;
function createMetadataAccountV2(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const mintAuthorityAccount = input.mintAuthority;
    const payerAccount = input.payer ?? context.payer;
    const updateAuthorityAccount = input.updateAuthority ?? context.identity.publicKey;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent;
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    signers.push(mintAuthorityAccount);
    keys.push({
        pubkey: mintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAuthorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: updateAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    if (rentAccount) {
        keys.push({
            pubkey: rentAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
        });
    }
    const data = getCreateMetadataAccountV2InstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createMetadataAccountV2 = createMetadataAccountV2;
//# sourceMappingURL=createMetadataAccountV2.js.map