"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createV1 = exports.getCreateV1InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getCreateV1InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['createV1Discriminator', s.u8()],
        ['name', s.string()],
        ['symbol', s.string()],
        ['uri', s.string()],
        ['sellerFeeBasisPoints', (0, umi_1.mapAmountSerializer)(s.u16(), '%', 2)],
        ['creators', s.option(s.array((0, types_1.getCreatorSerializer)(context)))],
        ['primarySaleHappened', s.bool()],
        ['isMutable', s.bool()],
        ['tokenStandard', (0, types_1.getTokenStandardSerializer)(context)],
        ['collection', s.option((0, types_1.getCollectionSerializer)(context))],
        ['uses', s.option((0, types_1.getUsesSerializer)(context))],
        [
            'collectionDetails',
            s.option((0, types_1.getCollectionDetailsSerializer)(context)),
        ],
        ['ruleSet', s.option(s.publicKey())],
        ['decimals', s.option(s.u8())],
        ['printSupply', s.option((0, types_1.getPrintSupplySerializer)(context))],
    ], { description: 'CreateV1InstructionData' }), (value) => ({
        ...value,
        discriminator: 42,
        createV1Discriminator: 0,
        symbol: value.symbol ?? '',
        primarySaleHappened: value.primarySaleHappened ?? false,
        isMutable: value.isMutable ?? true,
        collection: value.collection ?? (0, umi_1.none)(),
        uses: value.uses ?? (0, umi_1.none)(),
        collectionDetails: value.collectionDetails ?? (0, umi_1.none)(),
        ruleSet: value.ruleSet ?? (0, umi_1.none)(),
        decimals: value.decimals ?? (0, umi_1.none)(),
        printSupply: value.printSupply ?? (0, umi_1.none)(),
    }));
}
exports.getCreateV1InstructionDataSerializer = getCreateV1InstructionDataSerializer;
function createV1(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const masterEditionAccount = input.masterEdition ?? {
        ...programId,
        isWritable: false,
    };
    const authorityAccount = input.authority ?? context.identity;
    const payerAccount = input.payer ?? context.payer;
    const updateAuthorityAccount = input.updateAuthority ?? authorityAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: masterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionAccount, true),
    });
    if ((0, umi_1.isSigner)(mintAccount)) {
        signers.push(mintAccount);
    }
    keys.push({
        pubkey: (0, umi_1.publicKey)(mintAccount),
        isSigner: (0, umi_1.isSigner)(mintAccount),
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    if ((0, umi_1.isSigner)(updateAuthorityAccount)) {
        signers.push(updateAuthorityAccount);
    }
    keys.push({
        pubkey: (0, umi_1.publicKey)(updateAuthorityAccount),
        isSigner: (0, umi_1.isSigner)(updateAuthorityAccount),
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    const data = getCreateV1InstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 1427;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createV1 = createV1;
//# sourceMappingURL=createV1.js.map