"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deprecatedCreateMasterEdition = exports.getDeprecatedCreateMasterEditionInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getDeprecatedCreateMasterEditionInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        [
            'createMasterEditionArgs',
            (0, types_1.getCreateMasterEditionArgsSerializer)(context),
        ],
    ], { description: 'DeprecatedCreateMasterEditionInstructionData' }), (value) => ({
        ...value,
        discriminator: 2,
    }));
}
exports.getDeprecatedCreateMasterEditionInstructionDataSerializer = getDeprecatedCreateMasterEditionInstructionDataSerializer;
function deprecatedCreateMasterEdition(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const editionAccount = input.edition ??
        (0, accounts_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const printingMintAccount = input.printingMint;
    const oneTimePrintingAuthorizationMintAccount = input.oneTimePrintingAuthorizationMint;
    const updateAuthorityAccount = input.updateAuthority ?? context.identity;
    const printingMintAuthorityAccount = input.printingMintAuthority;
    const mintAuthorityAccount = input.mintAuthority;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const payerAccount = input.payer ?? context.payer;
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const oneTimePrintingAuthorizationMintAuthorityAccount = input.oneTimePrintingAuthorizationMintAuthority;
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    keys.push({
        pubkey: printingMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(printingMintAccount, true),
    });
    keys.push({
        pubkey: oneTimePrintingAuthorizationMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(oneTimePrintingAuthorizationMintAccount, true),
    });
    signers.push(updateAuthorityAccount);
    keys.push({
        pubkey: updateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    signers.push(printingMintAuthorityAccount);
    keys.push({
        pubkey: printingMintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(printingMintAuthorityAccount, false),
    });
    signers.push(mintAuthorityAccount);
    keys.push({
        pubkey: mintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAuthorityAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    signers.push(oneTimePrintingAuthorizationMintAuthorityAccount);
    keys.push({
        pubkey: oneTimePrintingAuthorizationMintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(oneTimePrintingAuthorizationMintAuthorityAccount, false),
    });
    const data = getDeprecatedCreateMasterEditionInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.deprecatedCreateMasterEdition = deprecatedCreateMasterEdition;
//# sourceMappingURL=deprecatedCreateMasterEdition.js.map