"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.migrate = exports.getMigrateInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getMigrateInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['migrateArgs', (0, types_1.getMigrateArgsSerializer)(context)],
    ], { description: 'MigrateInstructionData' }), (value) => ({ ...value, discriminator: 48 }));
}
exports.getMigrateInstructionDataSerializer = getMigrateInstructionDataSerializer;
function migrate(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const editionAccount = input.edition ??
        (0, accounts_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const tokenAccount = input.token;
    const tokenOwnerAccount = input.tokenOwner;
    const payerAccount = input.payer ?? context.payer;
    const authorityAccount = input.authority ?? context.identity;
    const collectionMetadataAccount = input.collectionMetadata;
    const delegateRecordAccount = input.delegateRecord;
    const tokenRecordAccount = input.tokenRecord ??
        (0, accounts_1.findTokenRecordPda)(context, {
            mint: (0, umi_1.publicKey)(mintAccount),
            token: (0, umi_1.publicKey)(tokenAccount),
        });
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    keys.push({
        pubkey: tokenOwnerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenOwnerAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, false),
    });
    keys.push({
        pubkey: delegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(delegateRecordAccount, false),
    });
    keys.push({
        pubkey: tokenRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenRecordAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getMigrateInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.migrate = migrate;
//# sourceMappingURL=migrate.js.map